@@ -123,8 +123,6 @@ class GpuDelegateImpl : public MailboxVideoFrameConverter::GpuDelegate {
       viz::SharedImageFormat format,
       const gfx::Size& size,
       const gfx::ColorSpace& color_space,
-      GrSurfaceOrigin surface_origin,
-      SkAlphaType alpha_type,
       gpu::SharedImageUsageSet usage) override {
     DCHECK(gpu_task_runner_->BelongsToCurrentThread());
 
@@ -139,8 +137,7 @@ class GpuDelegateImpl : public MailboxVideoFrameConverter::GpuDelegate {
     CHECK(shared_image_interface);
 
     return shared_image_interface->CreateSharedImage(
-        {format, size, color_space, surface_origin, alpha_type, usage,
-         "MailboxVideoFrameConverter"},
+        {format, size, color_space, usage, "MailboxVideoFrameConverter"},
         std::move(handle));
   }
 
@@ -341,13 +338,6 @@ void MailboxVideoFrameConverter::WrapSharedImageAndVideoFrameAndOutput(
   CHECK_EQ(frame->format(), origin_frame->format());
   CHECK(buffer_format);
 
-  // The target should be GL_TEXTURE_2D unless external sampling is being
-  // used, which in this context is equivalent to the passed-in buffer format
-  // being multiplanar as we never use per-plane sampling in this context.
-  uint32_t texture_target = gfx::BufferFormatIsMultiplanar(*buffer_format)
-                                ? GL_TEXTURE_EXTERNAL_OES
-                                : GL_TEXTURE_2D;
-
   VideoFrame::ReleaseMailboxCB release_mailbox_cb = base::BindOnce(
       [](scoped_refptr<base::SequencedTaskRunner> gpu_task_runner,
          base::WeakPtr<MailboxVideoFrameConverter> gpu_weak_ptr,
@@ -397,20 +387,12 @@ void MailboxVideoFrameConverter::WrapSharedImageAndVideoFrameAndOutput(
           ? frame->coded_size()
           : GetRectSizeFromOrigin(frame->visible_rect());
   scoped_refptr<VideoFrame> mailbox_frame = VideoFrame::WrapSharedImage(
-      frame->format(), shared_image, shared_image_sync_token, texture_target,
+      frame->format(), shared_image, shared_image_sync_token,
       std::move(release_mailbox_cb), coded_size, frame->visible_rect(),
       frame->natural_size(), frame->timestamp());
   mailbox_frame->set_color_space(frame->ColorSpace());
   mailbox_frame->set_hdr_metadata(frame->hdr_metadata());
   mailbox_frame->set_metadata(frame->metadata());
-
-  auto si_format = GetSharedImageFormat(*buffer_format);
-  mailbox_frame->set_shared_image_format_type(
-      media::SharedImageFormatType::kSharedImageFormat);
-  if (si_format.PrefersExternalSampler()) {
-    mailbox_frame->set_shared_image_format_type(
-        media::SharedImageFormatType::kSharedImageFormatExternalSampler);
-  }
   mailbox_frame->metadata().read_lock_fences_enabled = true;
   mailbox_frame->metadata().is_webgpu_compatible =
       frame->metadata().is_webgpu_compatible;
@@ -550,8 +532,7 @@ bool MailboxVideoFrameConverter::GenerateSharedImageOnGPUThread(
       gpu_delegate_->CreateSharedImage(std::move(gpu_memory_buffer_handle),
                                        GetSharedImageFormat(*buffer_format),
                                        shared_image_size, src_color_space,
-                                       kTopLeft_GrSurfaceOrigin,
-                                       kPremul_SkAlphaType, shared_image_usage);
+                                       shared_image_usage);
   if (!client_shared_image) {
     OnError(FROM_HERE, "Failed to create shared image.");
     return false;
